#
# spec file for package kernelshark
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kernelshark
Version:        2.3.1
Release:        1.2
Summary:        Visualisation tool for trace-cmd data
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Tools/Debuggers
URL:            https://git.kernel.org/pub/scm/utils/trace-cmd/kernel-shark.git
Source0:        kernelshark-%{version}.tar.xz
Patch01:        0001-kernelshark-fix-compiling-error-in-LatencyPlot.cpp.patch
BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  flex
BuildRequires:  freeglut-devel
BuildRequires:  libXi-devel
BuildRequires:  libXmu-devel
BuildRequires:  libjson-c-devel
BuildRequires:  libtracecmd-devel
BuildRequires:  libtraceevent-devel
BuildRequires:  libtracefs-devel
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-statemachine-devel
BuildRequires:  trace-cmd >= 3.1.0
Recommends:     trace-cmd

%description
trace-cmd reporting can be extremely verbose making it difficult to
analyse. kernelshark visualises the data so that it can be filtered
or trimmed.

%package devel
Summary:        Development files for kernelshark
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development files for kernelshark

%prep
%autosetup -p1

%build
# We would like to use _ttfontsdir macro but somehow the expension
# doesn't seem to work
%define fontname %{_datadir}/fonts/truetype/FreeSans.ttf

# The upstream project decided it is a good idea to have a directory
# called build with build script. The cmake macro expects to be able
# to create and use a directory called build. This leads to complete
# broken configuration. For the time being let's expand the relavent
# parts of the cmake macro by hand until it is fixed in upstream.
cmake \
    -DTT_FONT_FILE:PATH=%{fontname} \
    -D_INSTALL_PREFIX:PATH=%{_prefix} \
    -D_LIBDIR:PATH=%{_libdir} \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo \
    -DCMAKE_C_FLAGS="${CFLAGS:-%optflags}" \
    -DCMAKE_CXX_FLAGS="${CXXFLAGS:-%optflags}" \
    -DCMAKE_EXE_LINKER_FLAGS="%{?build_ldflags} -Wl,--as-needed -Wl,--no-undefined -Wl,-z,now" \
    -DCMAKE_SHARED_LINKER_FLAGS="%{?build_ldflags} -Wl,--as-needed -Wl,--no-undefined -Wl,-z,now" \
%if "%{?_lib}" == "lib64"
        -DLIB_SUFFIX=64 \
%endif
%if %suse_version <= 1500
        -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
%endif
    -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
    -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON \
    -DBUILD_SHARED_LIBS:BOOL=ON \
    -DCMAKE_COLOR_MAKEFILE:BOOL=OFF \
    -DPKG_CONGIG_DIR=%{_libdir}/pkgconfig

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
rm -rf %{buildroot}/%{_datadir}/polkit-1
sed -i -e 's/^Categories=.*/Categories=Development;Profiling/' %{buildroot}/%{_datadir}/applications/kernelshark.desktop
sed -i -e 's/^Version=1.5/Version=1.0/' %{buildroot}/%{_datadir}/applications/kernelshark.desktop

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/kernelshark
%{_bindir}/kshark-*
%{_libdir}/kernelshark
%{_libdir}/libkshark*.so.*
%{_datadir}/applications/kernelshark.desktop
%{_datadir}/icons/kernelshark
%license LICENSES/GPL-2.0
%license LICENSES/LGPL-2.1
%doc README

%files devel
%{_libdir}/libkshark*.so
%{_includedir}/kernelshark
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu Nov  7 2024 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (2.3.1)
  * Fixing bugs introduced when Porting KernelShark to Qt 6.
  * Porting KernelShark to Qt 6
- Fix build error
  * add 0001-kernelshark-fix-compiling-error-in-LatencyPlot.cpp.patch
* Wed Sep 13 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to latest upstream version (2.2.1)
  * Fix Capture if directory contains space
  * Fix segfault in libkshark-tepdata
* Tue Feb  7 2023 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (2.2.0)
  - Drop 0001-kernel-shark-Build-missed_event-as-GUI-plugin.patch
* Wed Aug 17 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (2.1.1)
  - Drop 0001-trace-cmd-fix-multiple-definition-compiler-errors.patch
  - Drop cmake-link-glut-libraries.patch
  - Drop makefile-bash.patch
  - Drop makefile-lib64.patch
  - Drop kernelshark-make-fontheight.patch
  - Add 0001-kernel-shark-Build-missed_event-as-GUI-plugin.patch
* Thu Jan 20 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (1.3)
- Fix the build
  - Add cmake-link-glut-libraries.patch
- (Build) Depend from libtracefs and libtraceevent packages
- spec file adjustments
  - %%setup --> %%autosetup
  - Drop kernelshark-rpmlintrc
* Sat Nov 14 2020 Dario Faggioli <dfaggioli@suse.com>
- Update to version 1.2
* Sat Nov 14 2020 Dario Faggioli <dfaggioli@suse.com>
- Filter version so that we have, e.g., "1.0" rather than "v1.0"
* Tue Oct  6 2020 Dario Faggioli <dfaggioli@suse.com>
- Switch obs_scm and set_version services to "disabled"
  * To enable the build on platform where set_version is not available
  * Disabled services are now run manually and the resulting files
    (kernelshark-v1.0.obscpio and kernelshark.obsinfo) are added to
    the repository
  * Running set_version has also fixed "Version:" in the spec file
* Tue Sep 29 2020 Dario Faggioli <dfaggioli@suse.com>
- Fix the build on (Tumbleweed) i586
  * In makefile-lib64.patch, using FIND_LIBRARY_USE_LIB64_PATHS
    results in CMake still putting the libraries in lib64
  * Switch to checking CMAKE_SIZEOF_VOID_P instead, works (and
    is similar to what we do in trace-cmd's Makefile, where we
    check LONG_BIT == 64)
* Thu Sep 24 2020 Dario Faggioli <dfaggioli@suse.com>
- Add a 0001-trace-cmd-fix-multiple-definition-compiler-errors.patch
  * Backport  of a fix for letting trace-cmd compile with gcc 10
- Add kernelshark-make-fontheight.patch
  * Backport of a fix for letting kernelshark compile with gcc 10
- Parallel build does not work for the `gui` target (build of kernelshark
  starts when trace-cmd hasn't finished building yet). Call the `trace-cmd`
  target before, explicitly, as a workaround
* Fri Aug 23 2019 Mel Gorman <mgorman@suse.de>
- Replace source tarball with _service file
* Tue Aug 20 2019 Mel Gorman <mgorman@suse.com>
- Avoid use of deprecated rpm macros
- Do not spawn unnecessary subshell for ldconfig
- Clean spec file with spec-cleaner
* Thu Aug  8 2019 Mel Gorman <mgorman@suse.com>
- Initial version 1.0.0
- Added makefile-bash.patch
  - Installs bash completion to correct location
  - Subsequently deletes file from package as it is supplied by trace-cmd
- Added makefile-lib64.patch
  - Installs libraries to lib64 on 64-bit builds
- Added kernelshark-rpmlintrc
  - Suggestion to enable PIC fails to build plugins
